#
# spec file for package ilmbase
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sonum 23
%global so_suffix -2_2-23
Name:           ilmbase
Version:        2.2.1
Release:        lp150.1.2
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://www.openexr.com
Source0:        http://download.savannah.nongnu.org/releases/openexr/%{name}-%{version}.tar.gz
Source1:        http://download.savannah.nongnu.org/releases/openexr/%{name}-%{version}.tar.gz.sig
Source2:        baselibs.conf
Source3:        https://savannah.nongnu.org/project/memberlist-gpgkeys.php?group=openexr&download=1#/ilmbase.keyring
#PATCH-FIX-OPENSUSE: testBox.patch allow fuzzy comparison of floats, doubles
Patch0:         testBox.patch
#PATCH-FIX-OPENSUSE: testBoxAlgo.patch allow fuzzy match of b12 == b2
Patch1:         testBoxAlgo.patch
# https://github.com/openexr/openexr/issues/219
# https://github.com/openexr/openexr/commit/20d043d017d4b752356bb76946ffdffaa9c15c72
Patch2:         ilmbase-halfExport.h-license.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
# Renamed to libilmbase6 to met the Shared Library Policy
Obsoletes:      IlmBase <= 1.0.1
Provides:       IlmBase = %{version}

%description
Base library for Industrial Light & Magic software (OpenEXR).

* Half is a class that encapsulates our 16-bit floating-point
   format.

* IlmThread is a thread abstraction library for use with OpenEXR and
   other software packages.  It currently supports pthreads and
   Windows threads.

* Imath implements 2D and 3D vectors, 3x3 and 4x4 matrices,
   quaternions and other useful 2D and 3D math functions.

* Iex is an exception-handling library.

%package devel
Summary:        Base library for ILM software (OpenEXR)
# Renamed to libilmbase6 to met the Shared Library Policy
License:        BSD-3-Clause AND GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libHalf%{sonum}
Requires:       libIex%{so_suffix}
Requires:       libIexMath%{so_suffix}
Requires:       libIlmThread%{so_suffix}
Requires:       libImath%{so_suffix}
Requires:       libstdc++-devel
Obsoletes:      IlmBase-devel <= 1.0.1
Provides:       IlmBase-devel = %{version}
Obsoletes:      libilmbase-devel <= 1.0.2
Provides:       libilmbase-devel = %{version}

%description devel
Devel files for ilmbase
Base library for Industrial Light & Magic software (OpenEXR).

%files devel
%doc AUTHORS ChangeLog COPYING NEWS README*
%{_includedir}/OpenEXR
%{_libdir}/libHalf.so
%{_libdir}/libIex.so
%{_libdir}/libImath.so
%{_libdir}/libIlmThread.so
%{_libdir}/libIexMath.so
%{_libdir}/pkgconfig/IlmBase.pc

%package -n libHalf%{sonum}
Summary:        16-bit floating-point encapsulation class for OpenEXR
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libHalf%{sonum}
%{summary}.

%post -n libHalf%{sonum} -p /sbin/ldconfig
%postun -n libHalf%{sonum} -p /sbin/ldconfig

%files -n libHalf%{sonum}
%{_libdir}/libHalf.so.*

%package -n libIexMath%{so_suffix}
Summary:        Exception-based vector/matrix library for OpenEXR
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libIexMath%{so_suffix}
%{summary}.

%post -n libIexMath%{so_suffix} -p /sbin/ldconfig
%postun -n libIexMath%{so_suffix} -p /sbin/ldconfig

%files -n libIexMath%{so_suffix}
%{_libdir}/libIexMath*.so.*

%package -n libIex%{so_suffix}
Summary:        Exception handling library for OpenEXR
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libIex%{so_suffix}
%{summary}.

%post -n libIex%{so_suffix} -p /sbin/ldconfig
%postun -n libIex%{so_suffix} -p /sbin/ldconfig

%files -n libIex%{so_suffix}
%{_libdir}/libIex-*.so.*

%package -n libIlmThread%{so_suffix}
Summary:        Thread abstraction library for OpenEXR
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libIlmThread%{so_suffix}
%{summary}.

%post -n libIlmThread%{so_suffix} -p /sbin/ldconfig
%postun -n libIlmThread%{so_suffix} -p /sbin/ldconfig

%files -n libIlmThread%{so_suffix}
%{_libdir}/libIlmThread*.so.*

%package -n libImath%{so_suffix}
Summary:        Vector/matrix library for OpenEXR
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libImath%{so_suffix}
%{summary}.

%post -n libImath%{so_suffix} -p /sbin/ldconfig
%postun -n libImath%{so_suffix} -p /sbin/ldconfig

%files -n libImath%{so_suffix}
%{_libdir}/libImath*.so.*

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p2

%build
./bootstrap
export PTHREAD_LIBS="-lpthread"
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
make %{?_smp_mflags} check

%changelog
* Mon Feb 12 2018 pgajdos@suse.com
- fix license of halfExport.h [bsc#774408]
  + ilmbase-halfExport.h-license.patch
* Wed Jan 17 2018 adam.majer@suse.de
- Update keyring and set keyring URL
* Mon Jan 15 2018 avindra@opensuse.org
- Update to version 2.2.1
  * Bumped version to track OpenEXR
- bump sonum and macroify it
- cleanup with spec-cleaner
* Sat Aug 12 2017 jengelh@inai.de
- Fix RPM groups. Diversify summaries.
- Drop useless --with-pic, this is only for static libs.
* Tue Aug  8 2017 ro@suse.de
- simplify check section in specfile and remove hack for gcc45
- add patches from debian to allow testsuite to pass
  - testBox.patch allow fuzzy comparison of floats, doubles
  - testBoxAlgo.patch allow fuzzy match of b12 == b2
* Fri Jan 23 2015 meissner@suse.com
- updated openexr.keyring from the savannah project page.
* Wed Jan 21 2015 p.drouand@gmail.com
- Update to version 2.2.0
  * Bumped version to track OpenEXR
- Bump so_suffix to 2_2-12 and libHalf11 to libHalf12 according to
  upstream changes
- removed arm-build.diff: upstream?
- removed fix-i586.patch: upstream?
- Bump so version in baselibs.conf
* Thu Aug 21 2014 fcrozat@suse.com
- Add obsoletes to baselibs.conf.
* Wed Nov 27 2013 mvyskocil@suse.com
- update to 2.1.0
  * Bumped version to track OpenEXR
    (Piotr Stanczyk)
- small cleanup of spec file
* Mon Jul 15 2013 mvyskocil@suse.com
- update to 2.0.1
  * Bumped version to track OpenEXR
    (Piotr Stanczyk)
- add gpg-offline based verification
- use downloads from nongnu.org, instead of github
* Fri Apr 12 2013 mvyskocil@suse.com
- update to 2.0.0
  * Bumped version to track OpenEXR
    (Piotr Stanczyk)
  * Numerous minor fixes, missing includes etc
  * Minor fixes for newer gcc versions and OS X.
    (misc)
  * Preparation for OpenEXR v2 release { remove message for final release }
    (Piotr Stanczyk)
  * Updated the so verison to 10
    (Piotr Stanczyk)
- obsoletes
  * 0001-Correcting-for-incorrect-license-section.patch
  * ilmbase-1.0.3-ucontext-i386.patch
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Sep 27 2012 idonmez@suse.com
- Correct baselibs.conf
* Fri Aug 24 2012 Rene.vanPaassen@gmail.com
- fix build on i586 platforms, by fixing error in declaration of the
  restorControlRegs function
* Wed Aug  8 2012 dmueller@suse.com
- fix build on non-x86 platforms with ucontext
* Tue Aug  7 2012 mvyskocil@suse.cz
- fix bnc#774408 - Proprietary licenses in ilmbase 1.0.3
  * 0001-Correcting-for-incorrect-license-section.patch
* Thu Aug  2 2012 mvyskocil@suse.cz
- update to 1.0.3
  * Updated the so version to 7.
  * Added support for enabling/disabling large stack optimisations, used in
    halfFunction.h.
  * Added ImathNoise.(h/cpp) files. Initializes Perlin noise to match the
    Renderman implmenetation.
  * Added SVD, eigenvalue solver, and procrustes fit calculations
    to ImathMatrixAlgo.
  * Added Imath::FrustumTest for frustum visibility testing.
  * Fixed a stack corruption in the matrix minorOf functions.
- provide a sane packaging conforming to shared library policy
  * source package is ilmbase, ilmbase-devel is the devel package
  * then libFoo$VERSION packages provides so files
* Tue Feb 28 2012 reddwarf@opensuse.org
- Link libIlmThread against lpthread, it was removed in SR#100972
* Sat Feb 18 2012 crrodriguez@opensuse.org
- revert visibility patch, it was not supposed
  to sneak-in yet.. [bnc#747565]
* Sat Jan 21 2012 jengelh@medozas.de
- Remove redundant sections (cf. specfile guidelines)
* Fri Jan 20 2012 crrodriguez@opensuse.org
- Reuse windows code to provide symbol visibility support.
  test suite passes, so unless it is incomplete or buggy
  this should be just fine, if something breaks, open a bug report.
* Mon Jul 26 2010 mvyskocil@suse.cz
- update to 1.0.2 (bug fix release)
- rename to libilmbase6 according Shared Library Policy
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Jun 13 2008 crrodriguez@suse.de
- remove unusable static libraries
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Oct 31 2007 mvyskocil@suse.cz
- inital release (version 1.0.1)
  * need for the update of OpenEXR to 1.6.1
